@@ -14,27 +14,22 @@
 from typing import Callable, Union
 
 import torch
+from torchmetrics import Metric
 from torchmetrics.metric import CompositionalMetric as _CompositionalMetric
 
-from pytorch_lightning.metrics import Metric
-from pytorch_lightning.utilities import rank_zero_warn
+from pytorch_lightning.metrics.utils import deprecated_metrics
 
 
 class CompositionalMetric(_CompositionalMetric):
-    r"""
-    This implementation refers to :class:`~torchmetrics.metric.CompositionalMetric`.
-
-    .. warning:: This metric is deprecated, use ``torchmetrics.metric.CompositionalMetric``. Will be removed in v1.5.0.
-    """
 
+    @deprecated_metrics(target=_CompositionalMetric)
     def __init__(
         self,
         operator: Callable,
         metric_a: Union[Metric, int, float, torch.Tensor],
         metric_b: Union[Metric, int, float, torch.Tensor, None],
     ):
-        rank_zero_warn(
-            "This `Metric` was deprecated since v1.3.0 in favor of `torchmetrics.Metric`."
-            " It will be removed in v1.5.0", DeprecationWarning
-        )
-        super().__init__(operator=operator, metric_a=metric_a, metric_b=metric_b)
+        """
+        .. deprecated::
+            Use :class:`torchmetrics.metric.CompositionalMetric`. Will be removed in v1.5.0.
+        """
